@@ -9,7 +9,7 @@
  * @copyright 2006 Sakamoto Kouichi
  * @license http://www.apache.org/licenses/LICENSE-2.0 Apache Software License 2.0
  * 
- * $Id: DocCommand.class.php 68 2006-04-01 14:27:55Z sakamoto $
+ * $Id: DocCommand.class.php 75 2006-04-06 13:35:12Z sakamoto $
  */
 
 /**
@@ -736,6 +736,78 @@ class AutoSOAP_Anno_VarCmd implements AutoSOAP_Anno_Command {
     } 
 } 
 
+/**
+ * Ԃ
+ * array(
+ *    Ώۂ̕ϐ(Ȃ'') => ,
+ *       E
+ *       E
+ *       E
+ *   )
+ *   : 
+ * 
+ * @package jp.servlet.AutoSOAP.Anno
+ * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
+ * @commandcode restriction_name
+ * @format 
+ */
+class AutoSOAP_Anno_RestrictionNameCmd implements AutoSOAP_Anno_Command {
+    private $result = null;
+    public function getCode()
+    {
+        return 'restriction_name';
+    } 
+    public function getResult()
+    {
+        return $this->result;
+    } 
+    public function execute($value)
+    {
+        $matchs = array();
+        if (preg_match("/^(?:(\S*)@)?(\S+)/i", $value, $matchs)) {
+            $this->result[$matchs[1]] = $matchs[2];
+        } else {
+            trigger_error('It failed in the match.(' . __CLASS__ . ')', E_USER_WARNING);
+        } 
+    } 
+} 
+
+/**
+ * V^ƔhԂ
+ * array(
+ *     => ^,
+ *       E
+ *       E
+ *       E
+ *   )
+ *   : 
+ * 
+ * @package jp.servlet.AutoSOAP.Anno
+ * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
+ * @commandcode restriction_type
+ * @format ^ 
+ */
+class AutoSOAP_Anno_RestrictionTypeCmd implements AutoSOAP_Anno_Command {
+    private $result = null;
+    public function getCode()
+    {
+        return 'restriction_type';
+    } 
+    public function getResult()
+    {
+        return $this->result;
+    } 
+    public function execute($value)
+    {
+        $matchs = array();
+        if (preg_match("/^(\S+)\s+(\S+)/i", $value, $matchs)) {
+            $this->result[$matchs[2]] = $matchs[1];
+        } else {
+            trigger_error('It failed in the match.(' . __CLASS__ . ')', E_USER_WARNING);
+        } 
+    } 
+} 
+
 /**
  * Ԃ
  * array(
@@ -770,9 +842,7 @@ class AutoSOAP_Anno_RestrictionCmd implements AutoSOAP_Anno_Command {
     public function execute($value)
     {
         $matchs = array();
-        if (!is_null($this->result)) {
-            trigger_error('It has already been set.(' . __CLASS__ . ')', E_USER_WARNING);
-        } else if (preg_match("/^(?:(\S*)@)?(\S+)\s+(.+)/i", $value, $matchs)) {
+        if (preg_match("/^(?:(\S*)@)?(\S+)\s+(.+)/i", $value, $matchs)) {
             $this->result[$matchs[1]][] = array($matchs[2] => $matchs[3]);
         } else {
             trigger_error('It failed in the match.(' . __CLASS__ . ')', E_USER_WARNING);
