@@ -9,7 +9,7 @@
  * @copyright 2006 Sakamoto Kouichi
  * @license http://www.apache.org/licenses/LICENSE-2.0 Apache Software License 2.0
  * 
- * $Id: class2SoapXsdVisitor.class.php 74 2006-04-05 14:29:06Z sakamoto $
+ * $Id: class2SoapXsdVisitor.class.php 75 2006-04-06 13:35:12Z sakamoto $
  */
 
 /**
@@ -45,17 +45,17 @@ class AutoSOAP_class2SoapXsdVisitor extends AutoSOAP_class2soapVisitor implement
     /**
      * \bhǉ
      */
-    public function appendMethod(AutoSOAP_ReflectionAccept $method, $annotation)
+    public function appendMethod(AutoSOAP_ReflectionAccept $method, $elemTypes)
     {
         $method_name = $method->getName();
 
-        /**
+        /*
          * NGXg\bhǉ
          */
         $request_name = $method_name . "Request";
         $request = $this->_schema->createComplexType($request_name);
 
-        /**
+        /*
          * p[^ǉ
          */
         $parameters = $method->getParameters()->accept($this);
@@ -69,7 +69,7 @@ class AutoSOAP_class2SoapXsdVisitor extends AutoSOAP_class2soapVisitor implement
         $request->add($this->_schema->createAnyAttribute("##other", "lax"));
         $this->_root->add($request);
 
-        /**
+        /*
          * ʖǉĂ
          */
         $alias = $this->_schema->createComplexType($method_name);
@@ -78,31 +78,20 @@ class AutoSOAP_class2SoapXsdVisitor extends AutoSOAP_class2soapVisitor implement
         $alias->add($alias_tmp);
         $this->_root->add($alias);
 
-        /**
+        /*
          * X|X\bhǉ
          */
         $response_name = $method_name . "Response";
-        $datatype = null;
-        $restriction = (isset($annotation['restrictions']['#return'])) ? $annotation['restrictions']['#return'] : null ;
-        $restriction_name = (isset($annotation['restriction_names']['#return'])) ? $annotation['restriction_names']['#return'] : null ;
-
-        if (is_array($annotation['return'])) {
-            $return_types = $annotation['return'][0]; 
-            // ^w肪Pp^[ȊOׂ͂NULLɂ
-            if (1 == count($return_types)) {
-                $datatype = $return_types[0];
-            } 
-        } 
-        $response = $this->_class2xsd->getDataTypeElement($response_name, $datatype, $restriction, $restriction_name);
+        $response = $this->_class2xsd->getDataTypeElement($response_name, $elemTypes['#return']);
         $this->_root->add($response);
     } 
 
     /**
      * ǉ
      */
-    public function appendParameter(AutoSOAP_ReflectionAccept $param, $datatype, $restriction, $restriction_name, $options)
+    public function appendParameter(AutoSOAP_ReflectionAccept $param, AutoSOAP_ElementType $elemType, $options)
     {
-        return $this->_class2xsd->getDataTypeElement($param->getName(), $datatype, $restriction, $restriction_name, $options);
+        return $this->_class2xsd->getDataTypeElement($param->getName(), $elemType, $options);
     } 
 }
 ?>
\ No newline at end of file
